@@ -17,12 +17,15 @@
 
 find_rtools <- function(...) {
   if (.Platform$OS.type == "unix") return(TRUE)
+  CXX <- Sys.which("g++")
+  if (nchar(CXX) > 0) return(TRUE)
   CXX <- system2(file.path(Sys.getenv("R_HOME"), "bin",
                            Sys.getenv("R_ARCH_BIN"), "R"),
                  args = "CMD config CXX", stdout = TRUE)
-  if (nchar(CXX) > 0) return(TRUE)
-  CXX <- Sys.which("g++")
-  if (nchar(CXX) > 0) return(TRUE)
+  if (!is.null(attributes(CXX)$status)) {
+    # do nothing
+  }
+  else if (nchar(CXX) > 0) return(TRUE)
   message("No C++ compiler found, so the following will probably not work.")
   message("See https://github.com/stan-dev/rstan/wiki/Installing-RStan-on-Windows#toolchain")
   return(FALSE)
